@@ -24,3 +24,14 @@ test_that("legacyids have non-scientific notation", {
     nchar(lakes_limno[lakes_limno$lagoslakeid == 448,]$legacyid),
     11)# [1] "4.51733E+12"
 })
+
+test_that("sampledate is parsed correctly", {
+
+  skip_on_cran()
+  skip_on_travis()
+  skip_on_appveyor()
+
+  epi_nutr <- lagosne_load()$epi_nutr
+
+  expect_equal(any(!is.na(epi_nutr$sampledate)), TRUE)
+})
